@@ -1,6 +1,6 @@
 # -*- coding:utf-8 -*-
 
-import msgpack
+import json
 
 
 class GraphReadWrite(object):
@@ -31,7 +31,7 @@ class GraphReadWrite(object):
             'node_indexes': node_indexes,
             'edge_indexes': edge_indexes
         }
-        msgpack.dump(dic, fp)
+        json.dump(dic, fp)
         # finished, close file
         fp.close()
 
@@ -39,7 +39,7 @@ class GraphReadWrite(object):
         # Open file soon to avoid building a big structure
         # if file cannot be written
         fp = open(path, 'r')
-        dic = msgpack.load(fp)
+        dic = json.load(fp)
         # reloading nodes :
         node_dump_id_to_node = {}
         for node_data in dic['nodes']:
